(* $Id: env.ml,v 1.1 1999/01/26 02:10:54 gerd Exp $
 * ----------------------------------------------------------------------
 *
 *)

open Db;;
open Db_types;;
open Dbll_adabas;;

let catch f =
  try
    f ()
  with
    Fatal_error(n,m) ->
      Printf.eprintf "Fatal error %d: %s\n" n m;
      flush stderr;
      raise Not_found
  | Error(n,m) ->
      Printf.eprintf "Error %d: %s\n" n m;
      flush stderr;
      raise Not_found
  | Transaction_error(n,m) ->
      Printf.eprintf "Transaction error %d: %s\n" n m;
      flush stderr;
      raise Not_found
  | Timeout_request ->
      prerr_endline "Timeout_request";
      raise Not_found
  | Timeout_lock ->
      prerr_endline "Timeout_lock";
      raise Not_found
  | Timeout_session ->
      prerr_endline "Timeout_session";
      raise Not_found
;;

let login = new Db_login.t;;
login # init_from_file "login.txt";;

let a = new t;;
(* catch (fun () -> a # open_conn login);; *)

let db = new Db.t a;;
db # connect login;;

let print_field f =
  match f with
    Decimal str    -> print_string "Decimal: ";    print_string str
  | Float str      -> print_string "Float:   ";    print_string str
  | Int i          -> print_string "Int:     ";    print_int i
  | Bigint str     -> print_string "Bigint:  ";    print_string str
  | Byte str       -> print_string "Byte:    ";    print_string str
  | Char str       -> print_string "Char:    ";    print_string str
  | Varchar str    -> print_string "VarChar: ";    print_string str
  | Bool b         -> print_string "Bool:    ";    print_string (if b then "true" else "false")
  | Large_text str -> print_string "Long:    ";    print_string str
  | Large_bin str  -> print_string "LongBin: ";    print_string str
  | Unknown        -> print_string "Unknown";
  | Null           -> print_string "NULL";
  | Date d         -> print_string "Date:    ";  print_string (date_to_string d)
  | Time t         -> print_string "Time:    ";  print_string (time_to_string t)
  | Timestamp t    -> print_string "Timestm: ";  
                      print_string (timestamp_to_string t)
;;


let rec print_column =
  function
      [] -> print_newline()
    | x :: l -> print_field x; print_newline(); print_column l
;;


let query1 () =
  a#prepare 0 "select * from entity where id < ?";

  a#execute 0 [| Int 10 |];

  a#prepare 0 "fetch using descriptor";

  try
    while true do
      let [| Decimal id; _; Varchar n; _; _ |] = a#execute 0 [||] in
      print_string id;
      print_string "   ";
      print_string n;
      print_newline()
    done
  with
    No_rows_found -> ()
;;


let query_cursor s =
  a # prepare 0 s;
  let _ = a # query 0 [| |] in
  let s = a # fetch 0 in
  Stream.iter
    (fun a ->
      print_column (Array.to_list a);
      print_newline())
    s;
  a # release 0
;;

let query2() = query_cursor "select * from entity";;

let query3() = query_cursor "select * from attrib_text";;

(*
let query3 () =
  a # prepare 0 "select * from attrib_text";
  let _ = a # execute 0 [||] in
  a # prepare 0 "fetch using descriptor";
  a # execute 0 [| |]
;;
*)

let db_query_cursor s =
  let stm = db # prepare_string s in
  let r = db # select stm [| |] in
  let s = db # open_result r in
  Stream.iter
    (fun a ->
      print_column (Array.to_list a);
      print_newline())
    s;
  db # close_result r
;;

let db_query2() = db_query_cursor "select * from entity";;

(* ======================================================================
 * History:
 * 
 * $Log: env.ml,v $
 * Revision 1.1  1999/01/26 02:10:54  gerd
 * first release
 *
 * 
 *)
